@@ -562,6 +562,15 @@ class IExportDialogFormButtons(Interface):
     cancel = jsaction.JSButton(title=_("Cancel"))
 
 
+class ThesaurusExportExtractSelectWidget(SelectWidget):
+    """Thesaurus export extract select widget"""
+    noValueMessage = _("(export all terms)")
+
+
+def ThesaurusExportExtractSelectWidgetFactory(field, request):
+    return FieldWidget(field, ThesaurusExportExtractSelectWidget(request))
+
+
 class ThesaurusExportEditForm(DialogAddForm):
     """Thesaurus export editor"""
 
@@ -572,6 +581,7 @@ class ThesaurusExportEditForm(DialogAddForm):
 
     buttons = button.Buttons(IExportDialogFormButtons)
     fields = field.Fields(IThesaurusExporterConfiguration)
+    fields['extract'].widgetFactory = ThesaurusExportExtractSelectWidgetFactory
 
     @property
     def title(self):
